@@ -9,6 +9,6 @@ from ppp_libmodule.exceptions import InvalidConfig
 
 class Config(BaseConfig):
     __slots__ = ('corenlp_server')
-    config_path_variable = 'PPP_NLP_CLASSICAL_CONFIG'
+    config_path_variable = 'PPP_QUESTIONPARSING_GRAMMATICAL_CONFIG'
     def parse_config(self, data):
         self.corenlp_server = data['corenlp_server']
